/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Table A24: "THE EFFECT OF ROBOTS ON EMPLOYMENT: ALTERNATIVE CONSTRUCTIONS OF EXPOSURE TO ROBOTS"
Table A25: "THE EFFECT OF ROBOTS ON WAGES: ALTERNATIVE CONSTRUCTIONS OF EXPOSURE TO ROBOTS"

The table presents estimates of the effects of exposure to robots the employment 
to population ratio (Table A24) and on the log hourly wages (Table A25)
- Panel A: Baseline construction of the instrument
- Panel B: Exposure computed using employment shares in 1990
- Panel C: Exposure computed using employment shares in 1980 from CBP
- Panel D: Including penetration of robots from Germany
- Panel E: Using penetration of robots among all European countries with data
- Panel F: Using penetration of robots without the adjutment term
- Panel G: Adjusting penetration of robots using robot prices

5.26.2018 (Revised 4/10/2019)
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

/*
Loop through all the variables used to construct the instrument:
- euro5_qo 		: baseline instrument (5 European countries: Denmark, Finland, France, Italy, Sweden)
-b90_euro5_qo 	: exposure computed using employment shares in 1990
-cbp_euro5_qo 	: exposure computed using employment shares in 1980 from CBP
-euro6_qo 		: Including penetration of robots in Germany
-euro9_qo  		: Including penetration of robots in Germany, Norway, Spain and UK (total 9 European countries)
-euro5_lv 		: penetration of robots without adjustment term
-euro5_price	: Adjusting penetration of robots using robot prices
*/
foreach instrument_def in euro5_qo b90_euro5_qo cbp_euro5_qo euro6_qo euro9_qo euro5_lv   euro5_price  {


********************************************************************************
**					Table A 24: The effect of robots on EMPLOYMENT			  **
********************************************************************************

********	Columns 1 - 3: Long Differences, 1990 - 2007 ***********
use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate

gen expo_robots=expof_`instrument_def'93_07

* Column 1: Weighted by population
reg d_emppriv_1990_2008 expo_robots $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1

* Column 2: Weighted by population, excluding zones with highest exposure
reg d_emppriv_1990_2008 expo_robots $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e2

* Column 3: Same weight to all czones
reg d_emppriv_1990_2008 expo_robots $demographics $industry_shares $other_shocks $region_effects, r cluster(state)
estimates store e3

********  	Column 7 : IV estimates 1990 - 2007,  weighted by population ********
gen us_adoption=(expof_us_adj04_07)*14/3 /*convert to 14 years change*/
ivreg2 d_emppriv_1990_2008 (us_adoption=expo_robots) $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e7

********	Columns 4 - 6: Stacked Differences, 1990 - 2000 and 2000 - 2007 ***********
use "${project}/clean_data/outcomes_stacked_czone.dta", clear
merge 1:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate
merge 1:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate

gen expo_robots=expof_`instrument_def'

* Column 4 : Weighted by population
reg d_emppriv expo_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990], r cluster(state)
estimates store e4

* Column 5: Weighted by population, excluding zones with highest exposure
reg d_emppriv expo_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990] if tag_exposure==1, r cluster(state)
estimates store e5

* Column 6: Same weight to all czones
reg d_emppriv expo_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year, r cluster(state)
estimates store e6

*Export each panel of Table A24 separatedly
estout e1 e2 e3 e4 e5 e6 e7 using "$project/results/table_robustness_instrument_employment_`instrument_def'.tex", style(tex) ///
varlabels(expo_robots "Exposure to robots" us_adoption "US robot adoption") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N, fmt(%7.0f %7.2f %7.1f) labels("Observations" "R-squared" "First-stage F-statistic")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(expo_robots us_adoption) ///
order(expo_robots us_adoption) 

********************************************************************************
**					Table A 25: The effect of robots on WAGES 				  **
********************************************************************************

********	Columns 1 - 3: Long Differences, 1990 - 2007 ***********
use czone d_hrwage_ln_1990_2008 nat_earners_weight_1990 wage_earners_1990 group using  "${project}/clean_data/outcomes_longdif_group.dta", clear 
merge m:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing(tag_exposure expof_us_adj04_07 expof_`instrument_def'93_07 $other_shocks)
encode state, gen(stcode)
encode group, gen(group_id)
gen expo_robots=expof_`instrument_def'93_07

* Column 1: Weighted by population
reghdfe d_hrwage_ln_1990_2008 expo_robots $demographics $industry_shares $other_shocks $region_effects [w=wage_earners_1990], absorb(group_id) cluster(stcode)
estimates store e1

* Column 2: Weighted by population, excluding zones with highest exposure
reghdfe d_hrwage_ln_1990_2008 expo_robots $demographics $industry_shares $other_shocks $region_effects [w=wage_earners_1990] if tag_exposure==1, absorb(group_id) cluster(stcode)
estimates store e2

* Column 3: Same weight to all czones
reghdfe d_hrwage_ln_1990_2008 expo_robots $demographics $industry_shares $other_shocks $region_effects [w=nat_earners_weight_1990], absorb(group_id) cluster(stcode)
estimates store e3

********  	Column 7 : IV estimates 1990 - 2007,  weighted by population ********
gen us_adoption=(expof_us_adj04_07)*14/3 /*convert to 14 years change*/
ivreghdfe d_hrwage_ln_1990_2008 $demographics $industry_shares $region_effects chinashock_iv_90_07 (us_adoption=expo_robots) [w=wage_earners_1990], a(group_id) cluster(stcode)
estimates store e7

********	Columns 4 - 6: Stacked Differences, 1990 - 2000 and 2000 - 2007 ***********
set matsize 5000
use czone year d_hrwage_ln nat_earners_weight_1990 wage_earners_1990 group using  "${project}/clean_data/outcomes_stacked_group.dta", clear 
merge m:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate
merge m:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate keepusing(tag_exposure expof_`instrument_def' $other_shocks_stacked)
encode state, gen(stcode)
encode group, gen(group_id)

gen expo_robots=expof_`instrument_def'

* Column 4 : Weighted by population
reghdfe d_hrwage_ln expo_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=wage_earners_1990], absorb(i.group_id##i.year) cluster(stcode)
estimates store e4

* Column 5: Weighted by population, excluding zones with highest exposure
reghdfe d_hrwage_ln expo_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=wage_earners_1990] if tag_exposure==1, absorb(i.group_id##i.year) cluster(stcode)
estimates store e5

* Column 6: Same weight to all czones
reghdfe d_hrwage_ln expo_robots $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=nat_earners_weight_1990], absorb(i.group_id##i.year) cluster(stcode)
estimates store e6

*Export each panel of Table A25 separatedly
estout e1 e2 e3 e4 e5 e6 e7 using "$project/results/table_robustness_instrument_wages_`instrument_def'.tex", style(tex) ///
varlabels(expo_robots "Exposure to robots" us_adoption "US robot adoption") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N, fmt(%7.0f %7.2f %7.1f) labels("Observations" "R-squared" "First-stage F-statistic")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(expo_robots us_adoption) ///
order(expo_robots us_adoption) 

}
