/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Table A28: "THE EFFECTS OF ROBOTS ON EMPLOYMENT AND WAGES: COVARIATES SELECTED BY LASSO"

The table presents estimates of the effects of exposure to robots on employment
and wages where the set of covariates is selected using a LASSO procedure 
(Belloni et al. 2014)
- Panel A: Change in the employment to population ratio, all workers
- Panel B: Change in log hourly wages

Warning: Lasso Procedure may take some time, especially when including
		 two-way interactions in the set of covariates (cols. 4 and 8)
		 
5.21.2018
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

*** Define macros for inputs of Lasso procedure separatedly for Long and Stacked Differences ***

******   LONG DIFFERENCES macros   ******
*Macro for Baseline set of covariates*
local baseline_covariates_longdif 	$demographics $industry_shares $other_shocks dum_div1 dum_div2 dum_div3 dum_div4 dum_div5 dum_div6 dum_div7 dum_div8 dum_div9  

*Expanded set of covariates (all covariates included in tables 2,3,4 and 6) plus additional demographics and industry shares*
local expanded_covariates_longdif 	$demographics $industry_shares $other_shocks dum_div1 dum_div2 dum_div3 dum_div4 dum_div5 dum_div6 dum_div7 dum_div8 dum_div9  ///
									ind_share_construction_1990 ind_share_mining_1990 ind_share_agriculture_1990 ind_share_utilities_1990 ind_share_research_1990 ipums_age16_25_1990 ipums_age26_35_1990 ipums_age36_45_1990 ipums_age46_55_1990 ipums_age56_65_1990  ///
									expo_capital_1990_2007 expo_itcapital_1990_2007  /// 
									expo_automa_us_1990_2007 expo_task_offshore expo_mexico_us_1990_2007 ///
									expo_decline_ifr_1970_1990

******   STACKED DIFFERENCES macros   ******
*Baseline set of covariates for stacked differences*
local baseline_covariates_stacked 	$demographics_stacked $industry_shares_stacked $other_shocks_stacked dum_div1 dum_div2 dum_div3 dum_div4 dum_div5 dum_div6 dum_div7 dum_div8 dum_div9 period2000 

*Expanded set of covariates (all covariates included in tables 2,3,4 and 6) plus additional demographics and industry shares*
local expanded_covariates_stacked 	$demographics_stacked $industry_shares_stacked $other_shocks_stacked dum_div1 dum_div2 dum_div3 dum_div4 dum_div5 dum_div6 dum_div7 dum_div8 dum_div9 period2000  ///
									ind_share_mining ind_share_construction  ind_share_agriculture ind_share_utilities ind_share_research ipums_age16_25 ipums_age26_35 ipums_age36_45 ipums_age46_55  ipums_age56_65 ///
									expo_capital expo_itcapital  ///
									expo_automa_us expo_task_offshore expo_mexico_us ///
									expo_decline_ifr_1970_1990 
				 											 
**********************************************************************
* Panel A - Change in Employment to population ratio - all workers	**
**********************************************************************

*************** Columns 1 - 4 LONG DIFFERENCES *******************
use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

tab division, gen(dum_div)
gen exposure_robots=expof_${expomes}93_07

*** Column 1: Baseline covariates ***

quietly: lassoShooting d_emppriv_1990_2008   `baseline_covariates_longdif'
local yvar=r(selected)
quietly: lassoShooting expof_${expomes}93_07  `baseline_covariates_longdif'
local xvar_e1=r(selected)
*Generate union of selected covariates *
local xTS : list yvar | xvar_e1 
*Estimate using selected covariates through LASSO procedure
reg d_emppriv_1990_2008 exposure_robots `xTS' [w=ipums_pop_1990], r cluster(state)
estimates store e1

*** Column 2: Extended covariates ***

quietly: lassoShooting d_emppriv_1990_2008   `expanded_covariates_longdif'
local yvar=r(selected)
quietly: lassoShooting expof_${expomes}93_07  `expanded_covariates_longdif'
local xvar_e2=r(selected)
*Generate union of selected covariates *
local xTS : list yvar | xvar_e2
*Estimate using selected covariates through LASSO procedure
reg d_emppriv_1990_2008 exposure_robots `xTS' [w=ipums_pop_1990], r cluster(state)
estimates store e2

*** Column 3: Extended covariates, separating the role of robots in automotive industry from other industries ***

quietly: lassoShooting expoc_${expomes}93_07  `expanded_covariates_longdif'
local xvarc_e3=r(selected)
quietly: lassoShooting expon_${expomes}93_07  `expanded_covariates_longdif'
local xvarn_e3=r(selected)
*Generate union of selected covariates *
local xTS : list yvar | xvarn_e3 
local xTS : list xTS  | xvarc_e3 
*Estimate using selected covariates through LASSO procedure
reg d_emppriv_1990_2008 exposure_robots expoc_${expomes}93_07 `xTS' [w=ipums_pop_1990], r cluster(state)
estimates store e3

*** Column 4 : Include all potential two-way interactions between baseline covariates (including Census and time dummies)

* Generate all twoway interactions
local i=1
foreach vari of local baseline_covariates_longdif{
local j=1
foreach varj of local expanded_covariates_longdif{
gen lasso_interaction_`i'_`j'=`vari'*`varj'
local j=`j'+1
}
local i=`i'+1
}

*Including all two-way interactions in the set of covariates when launching LASSO*
quietly: lassoShooting d_emppriv_1990_2008   `expanded_covariates_longdif' lasso_interaction_*
local yvar=r(selected)
quietly: lassoShooting expof_${expomes}93_07  `expanded_covariates_longdif' lasso_interaction_*
local xvar_e4=r(selected)
*Generate union of selected covariates*
local xTS : list yvar | xvar_e4
*Estimate using selected covariates through LASSO procedure
reg d_emppriv_1990_2008 exposure_robots `xTS' [w=ipums_pop_1990], r cluster(state)
estimates store e4


*************** Columns 5 - 8 STACKED DIFFERENCES *******************
use "${project}/clean_data/outcomes_stacked_czone.dta", clear
merge 1:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate
merge 1:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate
*merge covariates used in table 4*
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing(expo_decline_ifr_1970_1990)

tab division, gen(dum_div)
gen period2000=(year==2000)
gen exposure_robots=expof_${expomes}

*** Column 5: Baseline covariates ***

quietly: lassoShooting d_emppriv  		`baseline_covariates_stacked'
local yvar=r(selected)
quietly: lassoShooting expof_${expomes}	`baseline_covariates_stacked'
local xvar_e5=r(selected)
*Generate union of selected covariates *
local xTS : list yvar | xvar_e5 
*Estimate using selected covariates through LASSO procedure
reg d_emppriv exposure_robots `xTS' i.year [w=ipums_pop_1990], r cluster(state)
estimates store e5

*** Column 6: Extended covariates ***

quietly: lassoShooting d_emppriv  		`expanded_covariates_stacked'
local yvar=r(selected)
quietly: lassoShooting expoc_${expomes}	`expanded_covariates_stacked'
local xvar_e6=r(selected)
*Generate union of selected covariates *
local xTS : list yvar | xvar_e6
*Estimate using selected covariates through LASSO procedure
reg d_emppriv exposure_robots `xTS' i.year  [w=ipums_pop_1990], r cluster(state)
estimates store e6

*** Column 7: Extended covariates, separating the role of robots in automotive industry from other industries ***

quietly: lassoShooting expoc_${expomes} `expanded_covariates_stacked'
local xvarc_e7=r(selected)
quietly: lassoShooting expon_${expomes}	`expanded_covariates_stacked'
local xvarn_e7=r(selected)
*Generate union of selected covariates *
local xTS : list yvar | xvarc_e7 
local xTS : list xTS  | xvarn_e7
*Estimate using selected covariates through LASSO procedure 
reg d_emppriv exposure_robots expoc_${expomes} `xTS' i.year  [w=ipums_pop_1990], r cluster(state)
estimates store e7

*** Column 8 : Include all potential two-way interactions between baseline covariates (including Census and time dummies)

* Generate all twoway interactions
local i=1
foreach vari of local baseline_covariates_stacked{
local j=1
foreach varj of local expanded_covariates_stacked{
gen lasso_interaction_`i'_`j'=`vari'*`varj'
local j=`j'+1
}
local i=`i'+1
}

*Including all two-way interactions in the set of covariates when launching LASSO*
quietly: lassoShooting d_emppriv  		`expanded_covariates_stacked' lasso_interaction_*
local yvar=r(selected)
quietly: lassoShooting expoc_${expomes}	`expanded_covariates_stacked' lasso_interaction_*
local xvar_e8=r(selected)
*Generate union of selected covariates *
local xTS : list yvar | xvar_e8
*Estimate using selected covariates through LASSO procedure 
reg d_emppriv exposure_robots `xTS' i.year  [w=ipums_pop_1990], r cluster(state)
estimates store e8

*Export Panel A of Table A28*
estout e1 e2 e3 e4 e5 e6 e7 e8 using "$project/results/table_LASSO_emppriv.tex", style(tex) ///
varlabels(exposure_robots "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots) ///
order(exposure_robots) 


**********************************************************************
* 		Panel B - Change in Log Hourly Wages 		**
**********************************************************************

*************** Columns 1 - 4 LONG DIFFERENCES *******************
use czone d_hrwage_ln_1990_2008 wage_earners_1990 group using  "${project}/clean_data/outcomes_longdif_group.dta", clear 
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing(expo_capital expo_itcapital tag_exposure expo_decline_ifr_1970_1990 expo_automa_us_1990_2007 expo_task_offshore expo_mexico_us_1990_2007 expo*_${expomes}93_07 $other_shocks )
merge m:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

encode state, gen(stcode)
encode group, gen(group_id)

tab division, gen(dum_div)
gen exposure_robots=expof_${expomes}93_07

*** Column 1: Baseline covariates ***
preserve
collapse (firstnm) `baseline_covariates_longdif' (mean) d_hrwage_ln_1990_2008 [w=wage_earners_1990], by(czone) 
quietly: lassoShooting d_hrwage_ln_1990_2008  `baseline_covariates_longdif'
restore
local yvar=r(selected)
*Generate union of selected covariates *
local xTS : list yvar | xvar_e1 
*Estimate using selected covariates through LASSO procedure 
reghdfe d_hrwage_ln_1990_2008 exposure_robots `xTS' [w=wage_earners_1990], absorb(group_id) cluster(stcode)
estimates store e1

*** Column 2: Extended covariates ***
preserve
collapse (firstnm) `expanded_covariates_longdif' (mean) d_hrwage_ln_1990_2008 [w=wage_earners_1990], by(czone) 
quietly: lassoShooting d_hrwage_ln_1990_2008  `expanded_covariates_longdif'
restore
local yvar=r(selected)
*Generate union of selected covariates *
local xTS : list yvar | xvar_e2 
*Estimate using selected covariates through LASSO procedure 
reghdfe d_hrwage_ln_1990_2008 exposure_robots `xTS' [w=wage_earners_1990], absorb(group_id) cluster(stcode)
estimates store e2

*** Column 3: Extended covariates, separating the role of robots in automotive industry from other industries ***

*Generate union of selected covariates *
local xTS : list yvar | xvarn_e3
local xTS : list xTS  | xvarc_e3
*Estimate using selected covariates through LASSO procedure 
reghdfe d_hrwage_ln_1990_2008 exposure_robots expoc_${expomes}93_07 `xTS' [w=wage_earners_1990], absorb(group_id) cluster(stcode)
estimates store e3

*** Column 4 : Include all potential two-way interactions between baseline covariates (including Census and time dummies)

* Generate all twoway interactions
local i=1
foreach vari of local baseline_covariates_longdif{
local j=1
foreach varj of local expanded_covariates_longdif{
gen lasso_interaction_`i'_`j'=`vari'*`varj'
local j=`j'+1
}
local i=`i'+1
}

*Including all two-way interactions in the set of covariates when launching LASSO*
preserve
collapse (firstnm) `expanded_covariates_longdif' lasso_interaction_* (mean) d_hrwage_ln_1990_2008 [w=wage_earners_1990], by(czone) 
quietly: lassoShooting d_hrwage_ln_1990_2008  `expanded_covariates_longdif' lasso_interaction_*
restore
local yvar=r(selected)
*Generate union of selected covariates *
local xTS : list yvar | xvar_e4 
*Estimate using selected covariates through LASSO procedure 
reghdfe d_hrwage_ln_1990_2008 exposure_robots `xTS' [w=wage_earners_1990], absorb(group_id) cluster(stcode)
estimates store e4

*************** Columns 5 - 8 STACKED DIFFERENCES *******************
use czone year d_hrwage_ln* nat_earners_weight_1990 wage_earners_1990 group using  "${project}/clean_data/outcomes_stacked_group.dta", clear 
merge m:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate keepusing(tag_exposure expo_automa_us expo_task_offshore expo_mexico_us   $other_shocks_stacked expo*_${expomes})
merge m:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate
*merge covariates used in table 4*
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing(expo_capital expo_itcapital  expo_decline_ifr_1970_1990)

encode state, gen(stcode)
gen period2000=(year==2000)
encode group, gen(group_id)

tab division, gen(dum_div)
gen exposure_robots=expof_${expomes}

*** Column 5: Baseline covariates ***
preserve
collapse (firstnm) `baseline_covariates_stacked' (mean) d_hrwage_ln [w=wage_earners_1990], by(czone) 
quietly: lassoShooting d_hrwage_ln  `baseline_covariates_stacked'
restore
local yvar=r(selected)
*Generate union of selected covariates *
local xTS : list yvar | xvar_e5 
*Estimate using selected covariates through LASSO procedure 
reghdfe d_hrwage_ln exposure_robots `xTS' i.year  [w=wage_earners_1990], absorb(i.group_id##i.year) cluster(stcode)
estimates store e5

*** Column 6: Extended covariates ***
preserve
collapse (firstnm) `expanded_covariates_stacked' (mean) d_hrwage_ln [w=wage_earners_1990], by(czone) 
quietly: lassoShooting d_hrwage_ln  `expanded_covariates_stacked'
restore
local yvar=r(selected)
*Generate union of selected covariates *
local xTS : list yvar | xvar_e6
*Estimate using selected covariates through LASSO procedure 
reghdfe d_hrwage_ln exposure_robots `xTS' i.year  [w=wage_earners_1990], absorb(i.group_id##i.year) cluster(stcode)
estimates store e6

*** Column 7: Extended covariates, separating the role of robots in automotive industry from other industries ***

* Generate union of selected covariates (already identified when running regression for employment)*
local xTS : list yvar | xvarc_e7 
local xTS : list xTS  | xvarn_e7 
*Estimate using selected covariates through LASSO procedure 
reghdfe d_hrwage_ln exposure_robots expoc_${expomes} `xTS' i.year  [w=wage_earners_1990], absorb(i.group_id##i.year) cluster(stcode)
estimates store e7

*** Column 8 : Include all potential two-way interactions between baseline covariates (including Census and time dummies)

* Generate all twoway interactions
local i=1
foreach vari of local baseline_covariates_stacked{
local j=1
foreach varj of local expanded_covariates_stacked{
gen lasso_interaction_`i'_`j'=`vari'*`varj'
local j=`j'+1
}
local i=`i'+1
}

*Including all two-way interactions in the set of covariates when launching LASSO*
preserve
collapse (firstnm) `expanded_covariates_stacked' lasso_interaction_* (mean) d_hrwage_ln  [w=wage_earners_1990], by(czone)
quietly: lassoShooting d_hrwage_ln  `expanded_covariates_stacked' lasso_interaction_*
restore
local yvar=r(selected)
*Generate union of selected covariates *
local xTS : list yvar | xvar_e8 
*Estimate using selected covariates through LASSO procedure 
reghdfe d_hrwage_ln exposure_robots `xTS' i.year  [w=wage_earners_1990], absorb(i.group_id##i.year) cluster(stcode)
estimates store e8


*Export Panel B of Table A28*
estout e1 e2 e3 e4 e5 e6 e7 e8 using "$project/results/table_LASSO_hrwage_ln.tex", style(tex) ///
varlabels(exposure_robots "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots) ///
order(exposure_robots) 



