/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Table A23: "THE EFFECTS OF ROBOTS AND COMPUTERS ON EMPLOYMENT AND WAGES"

The table presents estimates of the effects of exposure to robots and several 
measures of the deployment of IT technologies and computers on employment and wages.
- Panel A: Controls for exposure to IT-intensive industries (from ASM)
- Panel B: Controls for exposure to computer-intensive industries (from CPS)
- Panel C: Controls for exposure to industry changes in computer use (from CPS)

5.21.2018 (Revised 4/3/2019)
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

/*
Loop through different controls:
- itintensity	: exposure to IT-intensive industries
- compintensity	: exposure to computer-intensive industries
- changecomp	: exposure to industry changes in computer use
*/

foreach trend in itintensity compintensity  changecomp {

* Define control variable for long-differences and stacked-differences analysis
if  "`trend'"=="itintensity"{
local expo_long     expo_it_intensity
local expo_stacked  expo_it_intensity
local label "Exposure to IT-intensive industries"
}
else if "`trend'"=="compintensity"{
local expo_long     expo_comp_intensity
local expo_stacked  expo_comp_intensity
local label "Exposure to computer-intensive industries"
}
else if "`trend'"=="changecomp"{
local expo_long     expo_comp_change
local expo_stacked  expo_comp_change
local label "Exposure to industry changes in computer use"
}

********************************************************************************
* 		Columns 1 - 4 : Change in the employment to population ratio 		   *
********************************************************************************

******* Columns 1 - 2 : Long Differences *******
use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

gen exposure_robots=expof_${expomes}93_07
gen expo_other=`expo_long'
sum expo_other [w=ipums_pop_1990]

* Column 1 : Weighted by population
reg d_emppriv_1990_2008 exposure_robots expo_other $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1

* Column 2 : Unweighted
reg d_emppriv_1990_2008 exposure_robots expo_other $demographics $industry_shares $other_shocks $region_effects, r cluster(state)
estimates store e2


******* Columns 3 - 4 : Stacked Differences *******
use "${project}/clean_data/outcomes_stacked_czone.dta", clear
merge 1:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate
merge 1:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate

gen exposure_robots=expof_${expomes}
gen expo_other=`expo_stacked'

* Column 3 : Weighted by population
reg d_emppriv exposure_robots expo_other $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990], r cluster(state)
estimates store e3

* Column 4 : Unweighted
reg d_emppriv exposure_robots expo_other $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year, r cluster(state)
estimates store e4

********************************************************************************
* 		Columns 5 - 8 : Change in log hourly wages					 		   *
********************************************************************************

******* Columns 5 - 6 : Long Differences *******
use czone d_hrwage_ln* nat_earners_weight_1990 wage_earners_1990 group using  "${project}/clean_data/outcomes_longdif_group.dta", clear 
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing( $other_shocks expof_${expomes}93_07 expo_*_intensity expo_comp_change)
merge m:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

encode state, gen(stcode)
encode group, gen(group_id)

gen exposure_robots=expof_${expomes}93_07
gen expo_other=`expo_long'

* Column 5 : Weighted by population
reghdfe d_hrwage_ln_1990_2008 exposure_robots expo_other $demographics $industry_shares $other_shocks $region_effects [w=wage_earners_1990], absorb(group_id) cluster(stcode)
estimates store e5

* Column 6 : Unweighted
reghdfe d_hrwage_ln_1990_2008 exposure_robots expo_other $demographics $industry_shares $other_shocks $region_effects [w=nat_earners_weight_1990], absorb(group_id) cluster(stcode)
estimates store e6

******* Columns 7 - 8 : Stacked Differences *******
use czone year d_hrwage_ln nat_earners_weight_1990 wage_earners_1990 group using  "${project}/clean_data/outcomes_stacked_group.dta", clear 
merge m:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate keepusing( $other_shocks_stacked expof_${expomes} expo_*_intensity expo_comp_change)
merge m:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate

encode state, gen(stcode)
encode group, gen(group_id)

gen exposure_robots=expof_${expomes}
gen expo_other=`expo_stacked'

* Column 7 : Weighted by population
reghdfe d_hrwage_ln exposure_robots expo_other $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=wage_earners_1990], absorb(i.group_id##i.year) cluster(stcode)
estimates store e7

* Column 8 : Unweighted
reghdfe d_hrwage_ln exposure_robots expo_other $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=nat_earners_weight_1990], absorb(i.group_id##i.year) cluster(stcode)
estimates store e8

*Export tables*
estout e1 e2 e3 e4 e5 e6 e7 e8 using "$project/results/table_altIT_`trend'.tex", style(tex) ///
varlabels(exposure_robots "Exposure to robots" expo_other "\multirow{2}{=}{`label'}") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots  expo_other ) ///
order(exposure_robots expo_other ) 

}
