/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Table A26: "THE EFFECTS OF ROBOTS ON EMPLOYMENT AND WAGES: THE ROLE OF OUTLIERS"

The table presents estimates of the effects of exposure to robots on employment
and wages.
- Panel A: Long differences for employment to population ratio, 1990 - 2007
- Panel B: Stacked differences for employment to population ratio, 1990 - 2000 and 2000 - 2007
- Panel C: Long differences for log hourly wages, 1990 - 2007
- Panel D: Stacked differences for log hourly wages, 1990 - 2000 and 2000 - 2007

5.21.2018 (Revised 4/10/2019)
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

/* 
Define program to identify observations with LARGE residuals (2 std dev. above or 
below the mean residuals of the unrestriced model ) and 
run regressions on a restricted sample without these outliers.
*/
cap program drop reg_outliers
program define reg_outliers, eclass 

syntax varlist(min=2 numeric) [if] [in] [aweight fweight], ///
		[CONTROLs(varlist numeric ts fv)]
		
		* Create convenient weight local
	    if ("`weight'"!="") local wt [`weight'`exp']
	
	* Parse varlist into y-vars and x-var
	local x_var=word("`varlist'",-1)
	local y_vars=regexr("`varlist'"," `x_var'$","")
	tempvar residual
	tempvar cons_sample
	
	quietly: reg `y_vars' `x_var' `controls'  `wt'  `if', r
	predict `residual' if e(sample)==1, resid
	quietly: sum `residual'
	gen `cons_sample'=(`residual'>-1.96*r(sd) & `residual'<1.96*r(sd)) if e(sample)==1
	reg `y_vars' `x_var' `controls'  `wt'  if `cons_sample'==1, r cluster(state)
end


********************************************************************************
** Panel A: Long differences for employment to population ratio, 1990 - 2007  **
********************************************************************************

* Create dataset for long differences
use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
gen detroit=(czone==11600)

*Column 1 : Weighted by population (Baseline)*
reg d_emppriv_1990_2008 expof_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1

*Column 2: Excludes Detroit*
reg d_emppriv_1990_2008 expof_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects [w=ipums_pop_1990] if detroit==0, r cluster(state)
estimates store e2

*Column 3 : Excludes observations with large residuals (identified through the program reg_outliers defined above)*
reg_outliers d_emppriv_1990_2008 expof_${expomes}93_07 [w=ipums_pop_1990], controls($demographics $industry_shares $other_shocks $region_effects) 
estimates store e3

*Column 4 : Robust regression as in Li (1985)*
rreg d_emppriv_1990_2008 expof_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects
estimates store e4

*Column 5 : Median regression*
qreg d_emppriv_1990_2008 expof_${expomes}93_07 $demographics $industry_shares $other_shocks $region_effects
estimates store e5

*Export Panel A of Table A26*
estout e1 e2 e3 e4 e5  using "$project/results/table_outliers_long_emppriv.tex", style(tex) ///
varlabels(expof_${expomes}93_07 "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(expof_${expomes}93_07) ///
order(expof_${expomes}93_07) 

***********************************************************************************************
** Panel B: Stacked differences for employment to population ratio, 1990-2000 and 2000-2007  **
***********************************************************************************************

* Create dataset for Stacked differences
use "${project}/clean_data/outcomes_stacked_czone.dta", clear
merge 1:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate
merge 1:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate
xtset czone year, delta(10)
sort czone year
gen detroit=(czone==11600)

*Column 1 : Weighted by population (Baseline)*
reg d_emppriv expof_${expomes} $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990], r cluster(state)
estimates store e1

*Column 2: Excludes Detroit*
reg d_emppriv expof_${expomes} $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year [w=ipums_pop_1990] if detroit==0, r cluster(state)
estimates store e2

*Column 3 : Excludes observations with large residuals (identified through the program reg_outliers defined above)*
reg_outliers d_emppriv expof_${expomes} [w=ipums_pop_1990], controls($demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year) 
estimates store e3

*Column 4 : Robust regression as in Li (1985)*
rreg d_emppriv expof_${expomes} $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year
estimates store e4

*Column 5 : Median regression*
qreg d_emppriv expof_${expomes} $demographics_stacked $industry_shares_stacked $other_shocks_stacked $region_effects i.year
estimates store e5

*Export Panel B of Table A26*
estout e1 e2 e3 e4 e5  using "$project/results/table_outliers_stacked_emppriv.tex", style(tex) ///
varlabels(expof_${expomes} "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(expof_${expomes}) ///
order(expof_${expomes}) 


********************************************************************************
** 		Panel C: Long differences for log hourly wages, 1990 - 2007  		  **
********************************************************************************

* Create dataset for long differences
use czone d_hrwage_ln_1990_2008 nat_earners_weight_1990 wage_earners_1990 group using  "${project}/clean_data/outcomes_longdif_group.dta", clear 
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing(expof_${expomes}93_07 $other_shocks)
merge m:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
encode state, gen(stcode)
encode group, gen(group_id)
gen detroit=(czone==11600)

*Column 1 : Weighted by population (Baseline)*
reghdfe d_hrwage_ln_1990_2008 expof_${expomes}93_07 $demographics $industry_shares $other_shocks  $region_effects [w=wage_earners_1990], absorb(group_id) cluster(stcode)
estimates store e1

*Column 2: Excludes Detroit*
reghdfe d_hrwage_ln_1990_2008 expof_${expomes}93_07 $demographics $industry_shares $other_shocks  $region_effects [w=wage_earners_1990] if detroit==0, absorb(group_id) cluster(stcode)
estimates store e2

*Column 3 : Excludes observations with large residuals (identified through the program reg_outliers defined above)*
reg_outliers d_hrwage_ln_1990_2008 expof_${expomes}93_07 [w=wage_earners_1990],  controls($demographics $industry_shares $other_shocks  $region_effects i.group_id) 
estimates store e3

*Column 4 : Robust regression as in Li (1985)*
rreg d_hrwage_ln_1990_2008 expof_${expomes}93_07 $demographics $industry_shares $other_shocks  $region_effects
estimates store e4

*Column 5 : Median regression*
qreg d_hrwage_ln_1990_2008 expof_${expomes}93_07 $demographics $industry_shares $other_shocks  $region_effects
estimates store e5

*Export Panel C of Table A26*
estout e1 e2 e3 e4 e5  using "$project/results/table_outliers_long_hrwage_ln.tex", style(tex) ///
varlabels(expof_${expomes}93_07 "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(expof_${expomes}93_07) ///
order(expof_${expomes}93_07) 


********************************************************************************
** Panel D: Stacked differences for log hourly wages, 1990-2000 and 2000-2007 **
********************************************************************************

* Create dataset for Stacked differences
set matsize 5000
use czone year d_hrwage_ln nat_earners_weight_1990 wage_earners_1990 group using  "${project}/clean_data/outcomes_stacked_group.dta", clear 
merge m:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate keepusing(expof_${expomes} $other_shocks_stacked)
merge m:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate
encode state, gen(stcode)
encode group, gen(group_id)
gen detroit=(czone==11600)

*Column 1 : Weighted by population (Baseline)*
reghdfe d_hrwage_ln expof_${expomes} $demographics_stacked $industry_shares_stacked $other_shocks_stacked  i.year $region_effects [w=wage_earners_1990], absorb(i.group_id##i.year) cluster(stcode)
estimates store e1

*Column 2: Excludes Detroit*
reghdfe d_hrwage_ln expof_${expomes} $demographics_stacked $industry_shares_stacked $other_shocks_stacked  i.year $region_effects [w=wage_earners_1990] if detroit==0, absorb(i.group_id##i.year) cluster(stcode)
estimates store e2

*Column 3 : Excludes observations with large residuals (identified through the program reg_outliers defined above)*
reg_outliers d_hrwage_ln expof_${expomes} [w=wage_earners_1990], controls($demographics_stacked $industry_shares_stacked $other_shocks_stacked  i.year $region_effects i.group_id##i.year)
estimates store e3

*Column 4 : Robust regression as in Li (1985)*
rreg d_hrwage_ln expof_${expomes} $demographics_stacked $industry_shares_stacked $other_shocks_stacked  i.year $region_effects
estimates store e4

*Column 5 : Median regression*
qreg d_hrwage_ln expof_${expomes} $demographics_stacked $industry_shares_stacked $other_shocks_stacked  i.year $region_effects
estimates store e5

*Export Panel D of Table A26*
estout e1 e2 e3 e4 e5  using "$project/results/table_outliers_stacked_hrwage_ln.tex", style(tex) ///
varlabels(expof_${expomes} "Exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(expof_${expomes}) ///
order(expof_${expomes}) 

