/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Table A22: "CONTROLLING FOR THE EFFECTS OF TRADE"

The table presents estimates of the effects of exposure to robots and changing
trade patterns on employment and wages.
- Panel A: Controls for exposure to imports from Mexico
- Panel B: Controls for exposure to industries with offshorable jobs
- Panel C: Controls for exposure to exports from Germany, Japan and South Korea

5.21.2018 (Revised 4/3/2019)
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */


/*
Loop through different sets of controls:
- mexico 	: exposure to imports from Mexico to US
- offhsoring: exposure to industries with a high share of offshorable jobs in 1990 (Autor and Dorn, 2013)
- automators: exposure to exports from Germany, Japan, and South Korea
*/
foreach source in  mexico offshoring automators {

if "`source'"=="mexico"{
*Note: concern here is offshoring to Mexico, which shows up as imports from Mexico to US*
local expo_long    expo_mexico_us_1990_2007
local expo_stacked expo_mexico_us
local label "Exposure to imports from Mexico"
}

else if "`source'"=="offshoring"{
*Note: concern here is outsourcing of tasks, both abroad or outside of manufacturing*
local expo_long     expo_task_offshore
local expo_stacked  expo_task_offshore
local label "Exposure to industries with offshorable jobs"
}

else if "`source'"=="automators"{
*Note: concern here is business stealing from Germany, Japan and Korea in world market*
local expo_long    expo_automa_us_1990_2007
local expo_stacked expo_automa_otch
local label "Exposure to exports from Germany, Japan, and South Korea"
}


********************************************************************************
* 		Columns 1 - 4 : Change in the employment to population ratio 		   *
********************************************************************************

******* Columns 1 - 2 : Long Differences *******
use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate

gen exposure_robots=expof_${expomes}93_07
gen expo_other=`expo_long'
gen expo_china=chinashock_iv_90_07

* Column 1 : Weighted by population
reg d_emppriv_1990_2008 exposure_robots expo_other expo_china $demographics $industry_shares expo_share_occ_routine_1990 $region_effects [w=ipums_pop_1990], r cluster(state)
estimates store e1

* Column 2 : Unweighted
reg d_emppriv_1990_2008 exposure_robots expo_other expo_china $demographics $industry_shares expo_share_occ_routine_1990 $region_effects, r cluster(state)
estimates store e2


******* Columns 3 - 4 : Stacked Differences *******
use "${project}/clean_data/outcomes_stacked_czone.dta", clear
merge 1:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate
merge 1:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate

gen exposure_robots=expof_${expomes}
gen expo_other=`expo_stacked'
gen expo_china=chinashock_iv

* Column 3 : Weighted by population
reg d_emppriv exposure_robots expo_other expo_china $demographics_stacked $industry_shares_stacked expo_share_occ_routine $region_effects i.year [w=ipums_pop_1990], r cluster(state)
estimates store e3

* Column 4 : Unweighted
reg d_emppriv exposure_robots expo_other expo_china $demographics_stacked $industry_shares_stacked expo_share_occ_routine $region_effects i.year, r cluster(state)
estimates store e4

********************************************************************************
* 		Columns 5 - 8 : Change in log hourly wages					 		   *
********************************************************************************

******* Columns 5 - 6 : Long Differences *******
use czone d_hrwage_ln* nat_earners_weight_1990 wage_earners_1990 group using  "${project}/clean_data/outcomes_longdif_group.dta", clear 
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing( $other_shocks expof_${expomes}93_07 `expo_long')
merge m:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
encode state, gen(stcode)
encode group, gen(group_id)

gen exposure_robots=expof_${expomes}93_07
gen expo_other=`expo_long'
gen expo_china=chinashock_iv_90_07

* Column 5 : Weighted by population
reghdfe d_hrwage_ln_1990_2008 exposure_robots expo_other expo_china $demographics $industry_shares expo_share_occ_routine_1990 $region_effects [w=wage_earners_1990], absorb(group_id) cluster(stcode)
estimates store e5

* Column 6 : Unweighted
reghdfe d_hrwage_ln_1990_2008 exposure_robots expo_other expo_china $demographics $industry_shares expo_share_occ_routine_1990 $region_effects [w=nat_earners_weight_1990], absorb(group_id) cluster(stcode)
estimates store e6

******* Columns 7 - 8 : Stacked Differences *******
use czone year d_hrwage_ln nat_earners_weight_1990 wage_earners_1990 group using  "${project}/clean_data/outcomes_stacked_group.dta", clear 
merge m:1 czone year using "${project}/clean_data/czones_exposure_stacked.dta", assert(3) nogenerate keepusing( $other_shocks_stacked expof_${expomes} `expo_stacked')
merge m:1 czone year using "${project}/clean_data/covariates_stacked.dta", assert(3) nogenerate
encode state, gen(stcode)
encode group, gen(group_id)

gen exposure_robots=expof_${expomes}
gen expo_other=`expo_stacked'
gen expo_china=chinashock_iv

* Column 7 : Weighted by population
reghdfe d_hrwage_ln exposure_robots expo_other expo_china $demographics_stacked $industry_shares_stacked expo_share_occ_routine $region_effects i.year [w=wage_earners_1990], absorb(i.group_id##i.year) cluster(stcode)
estimates store e7

* Column 8 : Unweighted
reghdfe d_hrwage_ln exposure_robots expo_other expo_china $demographics_stacked $industry_shares_stacked expo_share_occ_routine $region_effects i.year [w=nat_earners_weight_1990], absorb(i.group_id##i.year) cluster(stcode)
estimates store e8

*Export each panel of Table A22, separatedly *
estout e1 e2 e3 e4 e5 e6 e7 e8 using "$project/results/table_trade_`source'.tex", style(tex) ///
varlabels(exposure_robots "Exposure to robots" expo_other "\multirow{2}{=}{`label'}"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N r2, fmt(%7.0f %7.2f %7.1f %7.3f) labels("Observations" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(exposure_robots  expo_other  ) ///
order(exposure_robots expo_other  ) 

}
