/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
"Robots and Jobs: Evidence from US Labor Markets", by D. Acemoglu and P. Restrepo (2019)

This do file produces:
Table 7   : "THE EFFECTS OF ROBOTS ON EMPLOYMENT AND WAGES: IV ESTIMATES"
Table A30 : "ALTERNATIVE INFERENCE FOLLOWING BORUSYAK ET AL. (2018): IV ESTIMATES"

The tables present IV estimates of the effects of exposure to robots on employment
and wages for different time periods.


Warning: Estimates using Brousyak et al. procedure for changes in log hourly wage 
		(Table A30, columns 4 - 6) may take some time to process.


5.21.2018
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

*******************************************************
**Program to do inference a-la Borusyak et al. (2018)**
*******************************************************
cap program drop inference_bjh
program define inference_bjh, eclass

syntax varlist(min=2 numeric) [if] [in] [aweight fweight], ///
		[CONTROLs(varlist numeric ts fv) period(string)]

		* Create convenient weight local
	    if ("`weight'"!="") local wt [`weight'`exp']
		
		* Parse varlist into y-vars and x-var
		local x_var=word("`varlist'",-1)
		local y_var=regexr("`varlist'"," `x_var'$","")

/* We convert the dataset using the IV exposure to robots (shift-share) into a new dataset
of weighted shock-level aggregates, as described in Borusyak, Hull, and Jaravel (2018).*/
preserve
ssaggregate `y_var' `x_var' `wt'  `if', n(ind_id) s(share_ind)  controls("`controls'") 
gen industry_ifr19=""
replace industry_ifr19="agriculture" if ind_id==1
replace industry_ifr19="automotive" if ind_id==2
replace industry_ifr19="construction" if ind_id==3
replace industry_ifr19="electronics" if ind_id==4
replace industry_ifr19="food" if ind_id==5
replace industry_ifr19="furniture" if ind_id==6
replace industry_ifr19="manufacturing_other" if ind_id==7
replace industry_ifr19="metal_basic" if ind_id==8
replace industry_ifr19="metal_machinery" if ind_id==9
replace industry_ifr19="metal_products" if ind_id==10
replace industry_ifr19="mineral" if ind_id==11
replace industry_ifr19="mining" if ind_id==12
replace industry_ifr19="paper" if ind_id==13
replace industry_ifr19="petrochemicals" if ind_id==14
replace industry_ifr19="research" if ind_id==15
replace industry_ifr19="services" if ind_id==16
replace industry_ifr19="textiles" if ind_id==17
replace industry_ifr19="utilities" if ind_id==18
replace industry_ifr19="vehicles_other" if ind_id==19
* Merge the shift-share shocks using the industry_ifr as identifier (it coincides with ind_id, used in  ssaggregate
merge 1:1 industry_ifr19 using "${project}/clean_data/apr_measures_ifr19.dta" , assert(3) nogenerate
ivreg2 `y_var' (`x_var'=apr_${indmes}`period') [w=s_n], r
restore

end

***********************************************************************
**Loop over all periods presented in Table 7						 **
***********************************************************************

foreach time in 93_07 93_07_alt 93_14 00_07 00_14{


********************************************************************************
********* Columns 1 - 3 : Change in Employment to Population Ratio *************
***************************   Long Differences   *******************************

use "${project}/clean_data/outcomes_longdif_czone.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate

if ${inference_bjh}==1{
merge 1:1 czone using "${project}/clean_data/${shares}.dta", assert(3) nogenerate
rename (share_ind_agriculture share_ind_automotive share_ind_construction share_ind_electronics share_ind_food share_ind_furniture share_ind_manufacturing_other share_ind_metal_basic share_ind_metal_machinery share_ind_metal_products share_ind_mineral share_ind_mining share_ind_paper share_ind_petrochemicals share_ind_research share_ind_services share_ind_textiles share_ind_utilities share_ind_vehicles_other) ///
       (share_ind1 share_ind2 share_ind3 share_ind4 share_ind5 share_ind6 share_ind7 share_ind8 share_ind9 share_ind10 share_ind11 share_ind12 share_ind13 share_ind14 share_ind15 share_ind16 share_ind17 share_ind18 share_ind19)
}


* I) Import covariates measured at the beginning of the analysis period
* II) Identify dependent variable as change in employment to population ratio
* III) Convert adoption measure to XX-years difference to reflect the change in the dependent variable
* IV) Identify the weights for the regression and define macro for controls
if "`time'"=="93_07"{
local period `time'
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
gen depvar=d_emppriv_1990_2008	   
gen us_adoption=(expof_${usmes}04_07)*14/3 /*convert to a 14-year equivalent change*/
gen wvar=ipums_pop_1990
local controls_period  $industry_shares $demographics
local other_period     $other_shocks
}
else if "`time'"=="93_07_alt"{
local period 93_07
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
gen depvar=d_emppriv_1990_2008	   
gen us_adoption=(expof_${usmes}04_07)*4.5   /*APR in US 93-07 was of 0.77 
                                            (1 robot per k workers minus adjustment term of -0.33*ln(14.48/6.88))
										    APR in US 04-07 was of 0.17
                                            (0.33 robot per k workers minus adjustment term of -1*ln(14.48/12.27))*/
gen wvar=ipums_pop_1990
local controls_period  $industry_shares $demographics
local other_period     $other_shocks
}
else if "`time'"=="93_14"{
local period `time'
merge 1:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
gen depvar=d_emppriv_1990_2014
gen us_adoption=(expof_${usmes}04_14)*21/10 /*convert to a 21-year equivalent change*/
gen wvar=ipums_pop_1990
local controls_period  $industry_shares $demographics
local other_period     $other_shocks
}
else if "`time'"=="00_07"{
local period `time'
merge 1:1 czone using "${project}/clean_data/covariates_2000.dta", assert(3) nogenerate
gen depvar=d_emppriv_2000_2008
gen us_adoption=(expof_${usmes}04_07)*7/3 /*convert to a 7-year equivalent change*/
gen wvar=ipums_pop_2000
local controls_period  $industry_shares_2000 $demographics_2000
local other_period     $other_shocks_2000
}
else if "`time'"=="00_14"{
local period `time'
merge 1:1 czone using "${project}/clean_data/covariates_2000.dta", assert(3) nogenerate
gen depvar=d_emppriv_2000_2014
gen us_adoption=(expof_${usmes}04_14)*14/10 /*convert to a 14-year equivalent change*/
gen wvar=ipums_pop_2000
local controls_period  $industry_shares_2000 $demographics_2000
local other_period     $other_shocks_2000
}



*** Division dummies ***
* Table 7, Column 1
ivreg2 depvar (us_adoption=expof_${expomes}`period') $region_effects [w=wvar], r cluster(state) savefirst
quietly: estimates table _ivreg2_us_adoption, se
matrix b=r(coef)
estadd scalar first_stage_coef=b[1,1]
estimates store e1

*Inference a-la BJH, Table A30, Column 1: *
if ${inference_bjh}==1{
quietly: inference_bjh depvar us_adoption [w=wvar], controls($region_effects) period("`period'")
ereturn display
estimates store e1_bjh
}


*** Division dummies and Baseline covariates ***
* Table 7, Column 2
ivreg2 depvar (us_adoption=expof_${expomes}`period') `controls_period' $region_effects [w=wvar], r cluster(state) savefirst
quietly: estimates table _ivreg2_us_adoption, se
matrix b=r(coef)
estadd scalar first_stage_coef=b[1,1]
estimates store e2

*Inference a-la BJH, Table A30, Column 2*
if ${inference_bjh}==1{
quietly: inference_bjh depvar us_adoption [w=wvar], controls(`controls_period'  $region_effects) period("`period'")
ereturn display
estimates store e2_bjh
}


*** Division dummies, Baseline covariates, Trade and routine jobs ***
* Table 7, Column 3
ivreg2 depvar (us_adoption=expof_${expomes}`period') `controls_period' `other_period'  $region_effects [w=wvar], r cluster(state) savefirst
quietly: estimates table _ivreg2_us_adoption, se
matrix b=r(coef)
estadd scalar first_stage_coef=b[1,1]
estimates store e3

*Inference a-la BJH, Table A30, Column 3*
if ${inference_bjh}==1{
quietly: inference_bjh depvar us_adoption [w=wvar], controls(`controls_period' `other_period'  $region_effects) period("`period'")
ereturn display
estimates store e3_bjh
}

********************************************************************************
********* 			Columns 4 - 6 : Change in Log Hourly Wages	   *************
***************************   Long Differences   *******************************

use czone d_hrwage_ln_* wage_earners_* group using  "${project}/clean_data/outcomes_longdif_group.dta", clear 
merge m:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate keepusing( $other_shocks $other_shocks_2000 expof_${usmes}* expof_${expomes}`period')

if ${inference_bjh}==1{
merge m:1 czone using "${project}/clean_data/${shares}.dta", assert(3) nogenerate
rename (share_ind_agriculture share_ind_automotive share_ind_construction share_ind_electronics share_ind_food share_ind_furniture share_ind_manufacturing_other share_ind_metal_basic share_ind_metal_machinery share_ind_metal_products share_ind_mineral share_ind_mining share_ind_paper share_ind_petrochemicals share_ind_research share_ind_services share_ind_textiles share_ind_utilities share_ind_vehicles_other) ///
       (share_ind1 share_ind2 share_ind3 share_ind4 share_ind5 share_ind6 share_ind7 share_ind8 share_ind9 share_ind10 share_ind11 share_ind12 share_ind13 share_ind14 share_ind15 share_ind16 share_ind17 share_ind18 share_ind19)
}


* I) Import covariates measured at the beginning of the analysis period
* II) Identify dependent variable as change in Log Hourly Wage
* III) Convert adoption measure to XX-years difference to reflect the change in the dependent variable
* IV) Identify the weights for the regression and define macro for controls
if "`time'"=="93_07"{
local period `time'
merge m:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
gen depvar=d_hrwage_ln_1990_2008	   
gen us_adoption=(expof_${usmes}04_07)*14/3 /*convert to a 14-year equivalent change*/
gen wvar=wage_earners_1990
local controls_period  $industry_shares $demographics
local other_period     $other_shocks
}
else if "`time'"=="93_14"{
local period `time'
merge m:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
gen depvar=d_hrwage_ln_1990_2014
gen us_adoption=(expof_${usmes}04_14)*21/10 /*convert to a 21-year equivalent change*/
gen wvar=wage_earners_1990
local controls_period  $industry_shares $demographics
local other_period     $other_shocks
}
else if "`time'"=="00_07"{
local period `time'
merge m:1 czone using "${project}/clean_data/covariates_2000.dta", assert(3) nogenerate
gen depvar=d_hrwage_ln_2000_2008
gen us_adoption=(expof_${usmes}04_07)*7/3 /*convert to a 7-year equivalent change*/
gen wvar=wage_earners_2000
local controls_period  $industry_shares_2000 $demographics_2000
local other_period     $other_shocks_2000
}
else if "`time'"=="00_14"{
local period `time'
merge m:1 czone using "${project}/clean_data/covariates_2000.dta", assert(3) nogenerate
gen depvar=d_hrwage_ln_2000_2014
gen us_adoption=(expof_${usmes}04_14)*14/10 /*convert to a 14-year equivalent change*/
gen wvar=wage_earners_2000
local controls_period  $industry_shares_2000 $demographics_2000
local other_period     $other_shocks_2000
}
else if "`time'"=="93_07_alt"{
local period 93_07
merge m:1 czone using "${project}/clean_data/covariates_1990.dta", assert(3) nogenerate
gen depvar=d_hrwage_ln_1990_2008	   
gen us_adoption=(expof_${usmes}04_07)*4.5   /*APR in US 93-07 was of 0.77 
                                            (1 robot per k workers minus adjustment term of -0.33*ln(14.48/6.88))
										    APR in US 04-07 was of 0.17
                                            (0.33 robot per k workers minus adjustment term of -1*ln(14.48/12.27))*/
gen wvar=wage_earners_1990
local controls_period  $industry_shares $demographics
local other_period     $other_shocks
}

encode state, gen(stcode)
encode group, gen(group_id)

*** Division dummies ***
* Table 7, Column 4
ivreghdfe depvar $region_effects (us_adoption=expof_${expomes}`period')  [w=wvar], a(group_id) cluster(stcode) savefirst
quietly: estimates table _ivreg2_us_adoption, se
matrix b=r(coef)
estadd scalar first_stage_coef=b[1,1]
estimates store e4

*Inference a-la BJH: Table A30, Column 4*
if ${inference_bjh}==1{
set matsize 5000
quietly: inference_bjh depvar us_adoption [w=wvar], controls($region_effects i.group_id) period("`period'")
ereturn display
estimates store e4_bjh
}

*** Division dummies and Baseline covariates ***
* Table 7, Column 5
ivreghdfe depvar `controls_period' $region_effects  (us_adoption=expof_${expomes}`period') [w=wvar], a(group_id) cluster(stcode) savefirst
quietly: estimates table _ivreg2_us_adoption, se
matrix b=r(coef)
estadd scalar first_stage_coef=b[1,1]
estimates store e5

*Inference a-la BJH, Table A30, Column 5*
if ${inference_bjh}==1{
set matsize 5000
quietly: inference_bjh depvar us_adoption [w=wvar], controls(`controls_period'  $region_effects i.group_id) period("`period'")
ereturn display
estimates store e5_bjh
}

*** Division dummies, Baseline covariates, Trade and routine jobs ***
* Table 7, Column 6
ivreghdfe depvar  `controls_period'  `other_period'  $region_effects (us_adoption=expof_${expomes}`period') [w=wvar], a(group_id) cluster(stcode) savefirst
quietly: estimates table _ivreg2_us_adoption, se
matrix b=r(coef)
estadd scalar first_stage_coef=b[1,1]
estimates store e6

*Inference a-la BJH: Table A30, Column 6*
if ${inference_bjh}==1{
set matsize 5000
quietly: inference_bjh depvar us_adoption [w=wvar], controls(`controls_period'  `other_period'  $region_effects i.group_id) period("`period'")
ereturn display
estimates store e6_bjh
}

********************************************************************************
*Export each panel of Table 7*
estout e1 e2 e3 e4 e5 e6 using "$project/results/table7_`time'.tex", style(tex) ///
varlabels(us_adoption "US exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N first_stage_coef widstat, fmt(%7.0f %7.2f %7.2f %7.1f %7.3f) labels("Observations" "First-stage coefficient" "First-stage F-statistic" )) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(us_adoption) ///
order(us_adoption)

*Export each panel of Table A30 *
if ${inference_bjh}==1{
estout e1_bjh e2_bjh e3_bjh e4_bjh e5_bjh e6_bjh using "$project/results/table7_inference_bjh_`time'.tex", style(tex) ///
varlabels(us_adoption "US exposure to robots") ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N, fmt(%7.0f) labels("Observations")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(us_adoption) ///
order(us_adoption)
}

}


